@@ -3,9 +3,9 @@ from urllib import request
 
 
 def _cipher(z):
-    idx = [0xE, 0x3, 0x6, 0x8, 0x2]
+    idx = [0xe, 0x3, 0x6, 0x8, 0x2]
     mul = [2, 2, 5, 4, 3]
-    add = [0, 0xD, 0x10, 0xB, 0x5]
+    add = [0, 0xd, 0x10, 0xb, 0x5]
 
     b = []
     for i in range(len(idx)):
@@ -14,7 +14,7 @@ def _cipher(z):
         i = idx[i]
 
         t = a + int(z[i], 16)
-        v = int(z[t : t + 2], 16)
+        v = int(z[t:t + 2], 16)
         b.append(("%x" % (v * m))[-1])
 
     return "".join(b)
@@ -22,8 +22,7 @@ def _cipher(z):
 
 def _build_url(movie_hash):
     return "http://napiprojekt.pl/unit_napisy/dl.php?l=PL&f={}&t={}&v=other&kolejka=false&nick=&pass=&napios={}".format(
-        movie_hash, _cipher(movie_hash), os.name
-    )
+        movie_hash, _cipher(movie_hash), os.name)
 
 
 def download_for(movie_hash: str) -> bytes:
